@@ -547,6 +547,7 @@ class User(MojoSecrets, AbstractBaseUser, MojoModel):
         )
 
     def on_realtime_connected(self):
+        # should always self.refresh_from_db()
         meta = self.metadata or {}
         meta["realtime_connected"] = True
         try:
@@ -555,7 +556,7 @@ class User(MojoSecrets, AbstractBaseUser, MojoModel):
             # Fallback without timestamp if serialization fails
             meta["realtime_connected_at"] = None
         self.metadata = meta
-        self.atomic_save()
+        self.save(update_fields=["metadata"])
 
     def on_realtime_message(self, data):
         # Simple test handler logic for unit tests
@@ -568,11 +569,11 @@ class User(MojoSecrets, AbstractBaseUser, MojoModel):
 
         if mtype == "echo":
             payload = data.get("payload") if isinstance(data, dict) else None
-            return {
+            return {"response": {
                 "type": "echo",
                 "user_id": self.id,
                 "payload": payload
-            }
+            }}
 
         if mtype == "set_meta" and isinstance(data, dict):
             key = data.get("key")
@@ -581,11 +582,12 @@ class User(MojoSecrets, AbstractBaseUser, MojoModel):
                 meta = self.metadata or {}
                 meta[str(key)] = value
                 self.metadata = meta
-                self.atomic_save()
-                return {"type": "ack", "key": key, "value": value}
+                self.save(update_fields=["metadata"])
+                return {"response": {"type": "ack", "key": key, "value": value}}
+
 
         # Default ack for unrecognized messages
-        return {"type": "ack"}
+        return {"response": {"type": "ack"}}
 
     def on_realtime_disconnected(self):
         meta = self.metadata or {}
@@ -595,7 +597,7 @@ class User(MojoSecrets, AbstractBaseUser, MojoModel):
         except Exception:
             meta["realtime_disconnected_at"] = None
         self.metadata = meta
-        self.atomic_save()
+        self.save(update_fields=["metadata"])
 
     @classmethod
     def validate_jwt(cls, token, request=None):
