@@ -2,7 +2,7 @@ from mojo import decorators as md
 from mojo.apps.incident.parsers import ossec
 from mojo import JsonResponse
 from mojo.apps.incident import reporter
-
+from mojo.helpers import logit
 
 @md.POST('ossec/alert')
 @md.public_endpoint()
@@ -22,3 +22,10 @@ def on_ossec_alert_batch(request):
         alert["request_ip"] = request.ip
         reporter.report_event(alert.text, category="ossec", **alert)
     return JsonResponse({"status": True})
+
+
+@md.POST('ossec/firewall')
+@md.public_endpoint()
+def on_ossec_firewall(request):
+    logit.info("Firewall event received", request.DATA)
+    return JsonResponse({"status": True})
